import { Options } from "./makeApiRequest";
export declare type PredictionStatus = "starting" | "processing" | "succeeded" | "failed" | "canceled";
export declare type PredictionResponse = {
    id: string;
    version: string;
    urls: {
        get: string;
        cancel: string;
    };
    created_at: string;
    started_at: string | null;
    completed_at: string | null;
    status: PredictionStatus;
    input: Record<string, unknown>;
    output: Array<string>;
    error: null;
    logs: null | string;
    metrics: {
        /** In seconds */
        predict_time?: number;
    };
};
export declare type PredictionStatusObject = {
    id: string;
    version: string;
    get: () => Promise<PredictionStatusObject>;
    cancel: () => Promise<void>;
    /** Poll until the prediction is completed or failed
     * @param timeout The timeout in milliseconds
     */
    poll: (timeout?: number) => Promise<PredictionStatusObject>;
    created_at?: Date;
    started_at?: Date;
    completed_at?: Date;
    status: PredictionStatus;
    input: Record<string, unknown>;
    output: Array<unknown>;
    error: null;
    logs?: string;
    metrics: {
        predict_time?: number;
    };
};
export declare const convertPrediction: (options: Options, prediction: PredictionResponse) => PredictionStatusObject;
